@@ -70,6 +70,7 @@ class StoredEntity(Entity):
     def revert(self, create_if_nonexistent=True):
         self.load_root(create_if_nonexistent)
         self.load_manifest(create_if_nonexistent)
+        self.add_namespace('local', self.s.uri_base)
 
     @_init_obj_wrapper
     def store_root(self):
@@ -84,17 +85,18 @@ class StoredEntity(Entity):
         self.root = self.obj.getRoot()
 
     @_init_obj_wrapper
-    def put_stream(self, part_id, bytestream):
+    def put_stream(self, part_id, bytestream, commit_metadata_changes=False):
         self.obj.add_part(part_id, bytestream)
         part_uri = self.uh.parse_uri("%s/%s" % (self.uri, part_id))
         self.add_triple(self.uri, "ore:aggregates", part_uri)
         self.add_triple(part_uri, "dcterms:isPartOf", self.uri)
-        self.commit()
+        if commit_metadata_changes:
+            self.commit()
         if self.queue:
             self.log('w','stream', part_id=part_id)
 
     @_init_obj_wrapper
-    def del_stream(self, part_id):
+    def del_stream(self, part_id, commit_metadata_changes=False):
         self.obj.del_part(part_id)
         part_uri = self.uh.parse_uri("%s/%s" % (self.uri, part_id))
         self.del_triple(self.uri, "ore:aggregates", part_uri)
@@ -103,7 +105,8 @@ class StoredEntity(Entity):
             self.manifest.del_item(part_uri)
         except:
             pass
-        self.commit()
+        if commit_metadata_changes:
+            self.commit()
         if self.queue:
             self.log('d','stream', part_id=part_id)
 
@@ -128,6 +131,7 @@ class StoredEntity(Entity):
                 part_id = part_uri[len(self.obj.uri)+1:]
                 self.obj.add_part(part_id, self.parts_objs[part_uri].to_string())
                 self.add_triple(self.uri, "ore:aggregates", part_uri)
+                self.add_triple(part_uri, "dcterms:isPartOf", self.uri)
                 if self.queue:
                     self.log('w','part', part_id=part_id)
 
